==> privater-ddns_1.1.tar.bz2: include/config.php <==
<?php
// Definitionen
// ----------------------------------------------------------------------------
// Debugging im Log und dem Client anzeigen?
define("DEBUG",        false);
// Zeitstampel für DNS TXT-Eintrag und Protokoll
define("TIMESTAMP",    date("Ymd-His"));
// TTL für DNS-Einträge
define("TTL_SECONDS",  '60');
// Zu updatender Bind DNS Server
define("DNS_SERVER",   '127.0.0.1');
// Zu modifizierende DNS-Zone
define("DDNS_ZONE",    'ddns.onderka.com');
// Name des autorisierten Keys
define("KEY_NAME",     'ddns-update-key-main');
// Wert des autorisierten Keys
define("KEY_VALUE",    '5FTbontrallalaaHoppalajc1A==');
// Wert des Keys in der Debug-Ausgabe
define("KEY_VALUE_XX", 'secret_key_blah_blah_blah');
// Basis-Ordner (Apache DocumentRoot)
define("BASE_FOLDER",  $_SERVER['DOCUMENT_ROOT']);
// Sende-Port des Clients
define("RMT_PORT",     $_SERVER['REMOTE_PORT']);
// Zeitstempel Anfrage
define("QUERY_TIME",   $_SERVER['REQUEST_TIME']);
// Ordern für IP-Daten
define("DATA_FOLDER",  BASE_FOLDER.'/data/');
// Ordner für Protokolle
define("LOG_FOLDER",   BASE_FOLDER.'/log/');
// Protokoll für Ereignisse
define("LOG_FILE",     LOG_FOLDER.'/events.log');
// Protokoll für Debuggign
define("LOG_FILE_DBG", LOG_FOLDER.'/debug.log');
// Pfad zu 'nsupdate'
define("NSUPDATE",     '/usr/bin/nsupdate');
// Pfad zu 'logger' 
define("LOGGER",       '/usr/bin/logger');
// Kompletter Querystring aus URL
define("QUERYSTRING",  $_SERVER['QUERY_STRING']);
// Antwort für "Keine Änderung" nach DynDNS-Protokoll
define("RESP_NOCHG",  'nochg');
// Antwort für "Aktualisiert" nach DynDNS-Protokoll
define("RESP_OK",     'good');
// Aua!
define("RESP_OUCH",   '911');

// IP-Adresse (aus GET or Client-IP)
// ----------------------------------------------------------------------------
if ( filter_input(INPUT_GET, 'myip', FILTER_SANITIZE_SPECIAL_CHARS) ) {
   // IP aus GET myip nach DynDNS-Protokoll
   define("CLIENT_IP", filter_input(INPUT_GET, 'myip', FILTER_SANITIZE_SPECIAL_CHARS));
} else {
   // IP des Clients
   define("CLIENT_IP", $_SERVER['REMOTE_ADDR']);
}

// Benutzer unf Hostname (aus "Basic Authentication", aus GET oder nichts)
// ----------------------------------------------------------------------------
if ( isset($_SERVER['PHP_AUTH_USER']) ) {
   // Benutzer aus "Basic Authentication"
   define("AUTH_USER",   $_SERVER['PHP_AUTH_USER']);
   // Hostname aus GET "hostname" probieren
   $try_client = filter_input(INPUT_GET, 'hostname', FILTER_SANITIZE_SPECIAL_CHARS);
   if ( $try_client != "") {
      // GET "hostname" nicht leer, nehmen
      define("CLIENT_NAME", $try_client);
   } else {
      // GET "hostname" leer
      $try_client = filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS);
      if ( $try_client != "" ) {
         // GET "name" nicht leer, nehmen
         define("CLIENT_NAME", $try_client);
      } else {
         // GET "name" auch leer: Hostname = Benutzername setzen
         define("CLIENT_NAME", AUTH_USER);
      }
   }
} else {
   if ( isset($_GET['name']) ) {
      // Benutzer aus GET "name"
      define("AUTH_USER",   filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS));
      // Hostname aus GET "name"
      define("CLIENT_NAME", filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS));
   } else {
      // Kein Benutzer, kein Hostname - Ende
      define("AUTH_USER", "");
      define("CLIENT_NAME", "");
   }
}

// Passwort (aus "Basic Authentication", aus GET oder nichts)
// ----------------------------------------------------------------------------
if ( isset($_SERVER['PHP_AUTH_PW']) ) {
   // Passwort aus "Basic Authentication"
   define("AUTH_PASS", $_SERVER['PHP_AUTH_PW']);
} else {
   if (filter_input(INPUT_GET, 'pass', FILTER_SANITIZE_SPECIAL_CHARS)) {
      // Passwort aus GET "pass" probieren
      define("AUTH_PASS", filter_input(INPUT_GET, 'pass', FILTER_SANITIZE_SPECIAL_CHARS));
   } else {
      // Kein Passwort - Ende
      define("AUTH_PASS", "");
   }
}

// Alles da?
// ----------------------------------------------------------------------------
if ( AUTH_USER && AUTH_PASS && CLIENT_NAME && CLIENT_IP ) {
   // Alles da: Benutzer, Passwort, IP und Hostname
   define("DATA_COMPLETE", true);
} else {
   // Mindestens eins fehlt
   define("DATA_COMPLETE", false);
   // Was?
   $MISSING_DATA = array();
   if ( AUTH_USER == "") {
      // Benutzer
      array_push($MISSING_DATA, "AUTH_USER");
   }
   if ( AUTH_PASS == "" ) {
      // Passwort
      array_push($MISSING_DATA, "AUTH_PASS");
   }
   if ( CLIENT_NAME == "" ) {
      // Hostname
      array_push($MISSING_DATA, "CLIENT_NAME");
   }
   if ( CLIENT_IP == "" ) {
      // IP-Adresse
      array_push($MISSING_DATA, "CLIENT_IP");
   }
}
?>

==> privater-ddns_2.0.tar.bz2: include/config.php <==
<?php
// Definitionen
// ----------------------------------------------------------------------------
// Bind9 ("bind") oder dnsmasq ("dnsmasq")
define("DNSSOFTWARE",  'dnsmasq');
# SOA Email-Addresse. "@" als ".", Punkte vor @ als "\."
define("SOA_RNAME",    'hostmaster.example.com');
# SOA refresh [1200 .. 43200] (20 min ... 12 hours)
define("SOA_REFRESH",  '1200');
# SOA retry [120 .. 7200] (2 minutes .. 2 hours)
define("SOA_RETRY",    '120');
# SOA expiry [604800 .. 1209600] (1 week ... 2 weeks)
define("SOA_EXPIRY",   '604800');
# SOA minimale TTL [3600 .. 86400] (1 hour ... 1 day)
define("SOA_MINTTL",   '600');
// Debugging im Log und dem Client anzeigen?
define("DEBUG",        true);
// Zeitstampel für DNS TXT-Eintrag und Protokoll
define("TIMESTAMP",    date("Ymd-His"));
// TTL für DNS-Einträge
define("TTL_SECONDS",  '60');
// Zu updatender Bind DNS Server
define("DNS_SERVER",   '127.0.0.1');
// Zu modifizierende DNS-Zone
define("DDNS_ZONE",    'ddns.example.com');
// Name des autorisierten Keys
define("KEY_NAME",     'ddns-update-key-main');
// Wert des autorisierten Keys
define("KEY_VALUE",    'WRagvrFFFFUUUU111!!ELFgrwreasfC+jc1A==');
// Wert des Keys in der Debug-Ausgabe
define("KEY_VALUE_XX", 'secret_key_blah_blah_blah');
// Basis-Ordner (Apache DocumentRoot)
define("BASE_FOLDER",  $_SERVER['DOCUMENT_ROOT']);
// Sende-Port des Clients
define("RMT_PORT",     $_SERVER['REMOTE_PORT']);
// Zeitstempel Anfrage
define("QUERY_TIME",   $_SERVER['REQUEST_TIME']);
// Ordern für IP-Daten
define("DATA_FOLDER",  BASE_FOLDER.'/data/');
// Ordner für Protokolle
define("LOG_FOLDER",   BASE_FOLDER.'/log/');
// Protokoll für Ereignisse
define("LOG_FILE",     LOG_FOLDER.'/events.log');
// Protokoll für Debuggign
define("LOG_FILE_DBG", LOG_FOLDER.'/debug.log');
// Pfad zu dnsmasq Include-Ordner
define("DNSM_FOLDER",  BASE_FOLDER.'/dnsmasq/');
// Pfad zu 'nsupdate'
define("NSUPDATE",     '/usr/bin/nsupdate');
// Pfad zu 'logger' 
define("LOGGER",       '/usr/bin/logger');
// Kompletter Querystring aus URL
define("QUERYSTRING",  $_SERVER['QUERY_STRING']);
// Antwort für "Keine Änderung" nach DynDNS-Protokoll
define("RESP_NOCHG",  'nochg');
// Antwort für "Aktualisiert" nach DynDNS-Protokoll
define("RESP_OK",     'good');
// Aua!
define("RESP_OUCH",   '911');

// IP-Adresse (aus GET or Client-IP)
// ----------------------------------------------------------------------------
if ( filter_input(INPUT_GET, 'myip', FILTER_SANITIZE_SPECIAL_CHARS) ) {
   // IP aus GET myip nach DynDNS-Protokoll
   define("CLIENT_IP", filter_input(INPUT_GET, 'myip', FILTER_SANITIZE_SPECIAL_CHARS));
} else {
   // IP des Clients
   define("CLIENT_IP", $_SERVER['REMOTE_ADDR']);
}

// Benutzer unf Hostname (aus "Basic Authentication", aus GET oder nichts)
// ----------------------------------------------------------------------------
if ( isset($_SERVER['PHP_AUTH_USER']) ) {
   // Benutzer aus "Basic Authentication"
   define("AUTH_USER",   $_SERVER['PHP_AUTH_USER']);
   // Hostname aus GET "hostname" probieren
   $try_client = filter_input(INPUT_GET, 'hostname', FILTER_SANITIZE_SPECIAL_CHARS);
   if ( $try_client != "") {
      // GET "hostname" nicht leer, nehmen
      define("CLIENT_NAME", $try_client);
   } else {
      // GET "hostname" leer
      $try_client = filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS);
      if ( $try_client != "" ) {
         // GET "name" nicht leer, nehmen
         define("CLIENT_NAME", $try_client);
      } else {
         // GET "name" auch leer: Hostname = Benutzername setzen
         define("CLIENT_NAME", AUTH_USER);
      }
   }
} else {
   if ( isset($_GET['name']) ) {
      // Benutzer aus GET "name"
      define("AUTH_USER",   filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS));
      // Hostname aus GET "name"
      define("CLIENT_NAME", filter_input(INPUT_GET, 'name', FILTER_SANITIZE_SPECIAL_CHARS));
   } else {
      // Kein Benutzer, kein Hostname - Ende
      define("AUTH_USER", "");
      define("CLIENT_NAME", "");
   }
}

// Passwort (aus "Basic Authentication", aus GET oder nichts)
// ----------------------------------------------------------------------------
if ( isset($_SERVER['PHP_AUTH_PW']) ) {
   // Passwort aus "Basic Authentication"
   define("AUTH_PASS", $_SERVER['PHP_AUTH_PW']);
} else {
   if (filter_input(INPUT_GET, 'pass', FILTER_SANITIZE_SPECIAL_CHARS)) {
      // Passwort aus GET "pass" probieren
      define("AUTH_PASS", filter_input(INPUT_GET, 'pass', FILTER_SANITIZE_SPECIAL_CHARS));
   } else {
      // Kein Passwort - Ende
      define("AUTH_PASS", "");
   }
}

// Alles da?
// ----------------------------------------------------------------------------
if ( AUTH_USER && AUTH_PASS && CLIENT_NAME && CLIENT_IP ) {
   // Alles da: Benutzer, Passwort, IP und Hostname
   define("DATA_COMPLETE", true);
} else {
   // Mindestens eins fehlt
   define("DATA_COMPLETE", false);
   // Was?
   $MISSING_DATA = array();
   if ( AUTH_USER == "") {
      // Benutzer
      array_push($MISSING_DATA, "AUTH_USER");
   }
   if ( AUTH_PASS == "" ) {
      // Passwort
      array_push($MISSING_DATA, "AUTH_PASS");
   }
   if ( CLIENT_NAME == "" ) {
      // Hostname
      array_push($MISSING_DATA, "CLIENT_NAME");
   }
   if ( CLIENT_IP == "" ) {
      // IP-Adresse
      array_push($MISSING_DATA, "CLIENT_IP");
   }
}
?>
